<?php

namespace Guru\MessengerUser\Providers;

use Illuminate\Support\ServiceProvider;

class MessengerUserServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'messenger_user');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'messenger_user');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('messenger_user', function ($app) {
            return $this->app->make('Guru\MessengerUser\MessengerUser');
        });

// Bind MessengerUser to repository
        $this->app->bind(
            \Guru\MessengerUser\Interfaces\MessengerUserRepositoryInterface::class,
            \Guru\MessengerUser\Repositories\Eloquent\MessengerUserRepository::class
        );        // Bind MessengerMessage to repository
        $this->app->bind(
            \Guru\MessengerUser\Interfaces\MessengerMessageRepositoryInterface::class,
            \Guru\MessengerUser\Repositories\Eloquent\MessengerMessageRepository::class
        );

        $this->app->register(\Guru\MessengerUser\Providers\AuthServiceProvider::class);
        $this->app->register(\Guru\MessengerUser\Providers\EventServiceProvider::class);
        $this->app->register(\Guru\MessengerUser\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['messenger_user'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/messenger_user.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/messenger_user')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/messenger_user')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
